@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11817 2019-12-24 14:40:36Z Lavender $
+# $Id: __init__.py 11842 2020-01-07 13:51:23Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-12-24 23:40:36 +0900 (週二, 24 十二月 2019) $
-# $Revision: 11817 $
+# $Date: 2020-01-07 22:51:23 +0900 (週二, 07 一月 2020) $
+# $Revision: 11842 $
 
 import os
 import sys
@@ -358,7 +358,6 @@ def attachSettings(settingsDict, enablePaypal=False):
         
     if atmEnable:
         require('IUNO_SHOP_ATM_EXPIRED_HOURS', settingsDict)
-        require('IUNO_SHOP_ATM_PAYMENT_INFO', settingsDict)
 
     ADDING_OSCAR_DASHBOARD_NAVIGATION = {
         'label': _('Payment'),
@@ -607,7 +606,6 @@ def attachShopURLs(settings, urlpatterns):
         )
     else:
         from oscar.app import application as shop
-        from paypal.express.dashboard.app import application
         urlpatterns += patterns('',
             url(r'^shop/', shop.urls),
         )
@@ -645,15 +643,20 @@ def attachShopURLs(settings, urlpatterns):
     if hasattr(settings, 'IUNO_SHOP_ATM_ENABLE'):
         atmEnable = settings.IUNO_SHOP_ATM_ENABLE
 
-    if not VERSION >= (2, 0, 0):
-        if paypalEnable:
-            urlpatterns += patterns('',          
-                url(r'^shop/dashboard/paypal/express/', application.urls),
-                url(r'^checkout/paypal/place-order/(?P<basket_id>\d+)/$',
-                    views.SuccessResponseView.as_view(), 
-                    name='paypal-place-order'),
-                url(r'^checkout/paypal/', include('paypal.express.urls')),
-            )
+    if paypalEnable:
+        from paypal.express.dashboard import views as expressViews
+        urlpatterns += patterns('',          
+            url(r'^shop/dashboard/paypal/express/transactions/$', 
+                expressViews.TransactionListView.as_view(),
+                name='paypal-express-list'),
+            url(r'^shop/dashboard/paypal/express/transactions/(?P<pk>\d+)/$', 
+                expressViews.TransactionDetailView.as_view(),
+                name='paypal-express-detail'),
+            url(r'^checkout/paypal/place-order/(?P<basket_id>\d+)/$',
+                views.SuccessResponseView.as_view(), 
+                name='paypal-place-order'),
+            url(r'^checkout/paypal/', include('paypal.express.urls')),
+        )
 
     if cathaybkEnable:
         urlpatterns += patterns('',
@@ -742,7 +745,7 @@ ECPAY = 'ecpay'
 ECPAY_MAP = 'ecpay_map'
 ECPAY_LOGISTIC = 'ecpay_logistic'
 CATHAYBK = 'cathaybk'
-ATM = 'atm'
+ATM = 'ATM'
 
 class AllPay2(AllPay):
     def __init__(self, paymentConf, serviceMethod='post'):
