@@ -19,7 +19,7 @@ UserAddress = get_model('address', 'UserAddress')
 Order = get_model('order', 'Order')
 ShippingAddress = get_model('order', 'ShippingAddress')
 
-ATM = 'atm'
+ATM = 'ATM'
 
 TEXT = "text"
 INTEGER = "integer"
@@ -117,15 +117,17 @@ Order.ordererAddress = ordererAddress2
 # https://code.nuwainfo.com/trac/Mercurius/ticket/3296#ticket
 @property
 def useATM(self):
-    if Source.objects.filter(order=self, source_type__code=ATM).exists():
-        return True
+    
+    if Source.objects.filter(order=self, source_type__name=ATM).exists():
+        source = Source.objects.get(order=self, source_type__name=ATM)
+        return source
     else:
-        return False
+        return None
         
 @property
 def useATMPaymentSuccess(self):
-    if Source.objects.filter(order=self, source_type__code=ATM).exists():
-        source = Source.objects.get(order=self, source_type__code=ATM)
+    source = self.useATM
+    if source:
         if not source.reference == '-':
             return True
         else:
@@ -144,21 +146,15 @@ def useATMPaymentExpired(self):
     return False
         
 def setATMCode(self, code):
-    if Source.objects.filter(order=self, source_type__code=ATM).exists():
-        source = Source.objects.get(order=self, source_type__code=ATM)
+    source = self.useATM
+    if source:
         source.reference = code
         source.save()
 
-atmEnable = False
-if hasattr(settings, 'IUNO_SHOP_ATM_ENABLE'):
-    atmEnable = settings.IUNO_SHOP_ATM_ENABLE      
-if atmEnable:
-    Order.useATM = useATM
-    Order.useATMPaymentSuccess = useATMPaymentSuccess
-    Order.useATMPaymentExpired = useATMPaymentExpired
-    Order.setATMCode = setATMCode
-    Order.ATMBankCode = settings.IUNO_SHOP_ATM_PAYMENT_INFO['bank']
-    Order.ATMAccount = settings.IUNO_SHOP_ATM_PAYMENT_INFO['account']
+Order.useATM = useATM
+Order.useATMPaymentSuccess = useATMPaymentSuccess
+Order.useATMPaymentExpired = useATMPaymentExpired
+Order.setATMCode = setATMCode    
     
 @property
 def isOrdererAddress(self):
