@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11817 2019-12-24 14:40:36Z Lavender $
+# $Id: views.py 11826 2020-01-01 08:07:12Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-12-24 23:40:36 +0900 (週二, 24 十二月 2019) $
-# $Revision: 11817 $ 
+# $Date: 2020-01-01 17:07:12 +0900 (週三, 01 一月 2020) $
+# $Revision: 11826 $ 
 
 import json
 import logging
@@ -91,7 +91,7 @@ ALLPAY = 'allpay'
 ECPAY = 'ecpay'
 ECPAY_LOGISTIC = 'ecpay_logistic'
 ECPAY_MAP = 'ecpay_map'
-ATM = 'atm'
+ATM = 'ATM'
 
 CATHAYBK_CREDIT = 'cathaybk-credit' # /cathaybk-credit/checkxml/
 CATHAYBK_CUP = 'cathaybk-cup' # /cathaybk-cup/checkxml/
@@ -137,22 +137,22 @@ def get_context_data(self, **kwargs):
         atmEnable = settings.IUNO_SHOP_ATM_ENABLE
     
     if ecpayEnable:
-        kwargs['ecpay'] = buildAPIForm(submission, self.request, 'ecpay')
+        kwargs['ecpay'] = buildAPIForm(submission, self.request, ECPAY)
         kwargs['ecpay_map'] = \
-            buildAPIForm(submission, self.request, 'ecpay_map')
+            buildAPIForm(submission, self.request, ECPAY_MAP)
         kwargs['ecpay_logistic'] = \
-            buildAPIForm(submission, self.request, 'ecpay_logistic')
+            buildAPIForm(submission, self.request, ECPAY_LOGISTIC)
     if allpayEnable:
-        kwargs['allpay'] = buildAPIForm(submission, self.request, 'allpay')
+        kwargs['allpay'] = buildAPIForm(submission, self.request, ALLPAY)
     if spgatewayEnable:
         kwargs['spgateway'] = buildAPIForm(
-                                        submission, self.request, 'spgateway')
+                                        submission, self.request, SPGATEWAY)
     if cathaybkEnable:
         kwargs['cathaybk'] = buildAPIForm(
                                         submission, self.request, 'cathaybk')                                       
     if atmEnable:
-        kwargs['atm'] = buildAPIForm(
-                                        submission, self.request, 'atm') 
+        kwargs['ATM'] = buildAPIForm(
+                                        submission, self.request, ATM) 
 
     if self.request.session.get('logisticMap'):
         mapData = json.loads(self.request.session['logisticMap'])
